<?php

namespace backend\modules\theme\controllers;

use common\models\ThemeFiles;
use yii;
use yii\web\NotFoundHttpException;
use yii\web\UploadedFile;

class ThemeFileController extends \yii\web\Controller
{
    public function actionIndex()
    {
        return $this->render('index');
    }

    public function actionUpload()
    {
        $model = new ThemeFiles();

        if ($model->load(Yii::$app->request->post())) { //&& $model->save()

            // get the uploaded file instance. for multiple file uploads
            // the following data will return an array
            $theme_file = UploadedFile::getInstance($model, 'file');

            $model->file = $theme_file;
            $ext = $model->file->extension;
            $allowed = array('js', 'css', 'html');
            if (in_array($ext, $allowed)) {
                // the path to save file,
                $folderPath = yii::getAlias('@storage/private/theme-assets/') . $model->theme_code;
                if (!is_dir($folderPath)) {
                    mkdir($folderPath);
                }
                $path = $folderPath . '/' . $model->file_code;
                if ($model->save(false)) {
                    $model->file->saveAs($path);
                    Yii::$app->getSession()->setFlash($model->file_code, [
                        'type' => 'warning',
                        'duration' => 3000,
                        'icon' => 'fa fa-file',
                        'message' => '' . $model->file_code . ' Uploading...',
                        'showSeparator' => true,
                        'title' => ' File Upload',
                        'showProgressbar' => true,
                        'positonY' => 'top',
                        'positonX' => 'right'
                    ]);
                    Yii::$app->getSession()->setFlash('success', [
                        'type' => 'success',
                        'duration' => 5000,
                        'icon' => 'fa fa-file',
                        'message' => ' File successfully Uploaded',
                        'showSeparator' => true,
                        'title' => ' File Upload',
                        'delay' => 3000,
                        'positonY' => 'top',
                        'positonX' => 'right'
                    ]);
                } else {
                    echo 'Error';
                    exit();
                }
            } else {
                Yii::$app->getSession()->setFlash('alert', [
                    'type' => 'danger',
                    'duration' => 5000,
                    'icon' => 'fa fa-envira',
                    'message' => 'File type miss match! ',
                    'showSeparator' => true,
                    'title' => 'Error',
                    'showProgressbar' => true,
                    'positonY' => 'top',
                    'positonX' => 'right'
                ]);
            }
        }

        return $this->redirect(['theme/files', 'id' => $model->theme_id]);
    }

    public function actionEditor($id)
    {
        $model = $this->findModel($id);
        if ($model->load(Yii::$app->request->post())) {
            $file = yii::getAlias('@storage/private/theme-assets/') . $model->theme_code . '/' . $model->file_code;
            if($model->fileContent){
                file_put_contents($file, $model->fileContent);
                Yii::$app->getSession()->setFlash('fileContentUpdated', [
                    'type' => 'success',
                    'duration' => 5000,
                    'icon' => 'fa fa-file',
                    'message' => ' File Saved',
                    'showSeparator' => true,
                    'title' => ' Code Editor',
                    'positonY' => 'top',
                    'positonX' => 'right'
                ]);
            }
        }

        return $this->render('editor', [
            'model' => $model,
            'theme_id'=>$model->theme_id,
        ]);
    }

    public function actionDelete($id)
    {
        $model = $this->findModel($id);
        if ($model->load(Yii::$app->request->post())) {
            $file = yii::getAlias('@storage/private/theme-assets/') . $model->theme_code . '/' . $model->file_code;
            unlink($file);
            $this->findModel($id)->delete();
            Yii::$app->getSession()->setFlash('Delete Theme file', [
                'type' => 'success',
                'duration' => 5000,
                'icon' => 'fa fa-file',
                'message' => ' File successfully Deleted',
                'showSeparator' => true,
                'title' => ' Theme Files',
                'positonY' => 'top',
                'positonX' => 'right'
            ]);

            return $this->redirect(['theme/files', 'id' => $model->theme_id]);
        }else{

            return $this->render(['editor', 'id' => $model->id ,'theme_id' => $model->theme_id]);
        }
    }

    protected function findModel($id)
    {
        if (($model = ThemeFiles::findOne($id)) !== null) {
            return $model;
        } else {
            throw new NotFoundHttpException('The requested page does not exist.');
        }
    }

}
