<?php
namespace frontend\controllers;

use common\models\Category;
use common\models\CategoryFiles;
use common\models\Website;
use Yii;
use frontend\models\ContactForm;
use yii\web\Controller;
use yii\httpclient\Client;
use yii\db\Query;
use common\models\Theme;
use yii\twig;
use Twig_Loader_Filesystem;
use Twig_Environment;

/**
 * Site controller
 */
class SiteController extends Controller
{
    /**
     * @inheritdoc
     */
    public function actions()
    {
        return [
            'error' => [
                'class' => 'yii\web\ErrorAction'
            ],
            'captcha' => [
                'class' => 'yii\captcha\CaptchaAction',
                'fixedVerifyCode' => YII_ENV_TEST ? 'testme' : null
            ],
            'set-locale' => [
                'class' => 'common\actions\SetLocaleAction',
                'locales' => array_keys(Yii::$app->params['availableLocales'])
            ]
        ];
    }

    public function actionIndex()
    {

        $domain = $_SERVER['HTTP_HOST'];
        $website = Website::find()->where(['domain_name' => $domain])->one();
        $businessId = $website->business_id;
        $themeId = $website->theme_id;
        if (!$businessId) {
            echo 'Business not found';
            exit();
        } else {
            $theme = Theme::find()->where(['id' => $themeId])->one();
            if (!$theme) {
                echo 'theme not found';
                exit();
            } else {
                $category = Category::find()->where(['id' => $theme->category_id])->one();
                if (!$category) {
                    echo 'category not found';
                    exit();
                } else {
                    $categoryFiles = CategoryFiles::find()->where(['category_id' => $category->id])->all();
                    foreach ($categoryFiles as $file) {
                        $path = yii::getAlias('@storage/private/theme-assets/') . $theme->code . '/';
                        $loader = new Twig_Loader_Filesystem($path);
                        $twig = new Twig_Environment($loader);
                        $client = new Client();
                        $response = $client->createRequest()
                            ->setMethod('get')
                            ->setUrl('http://libromi.com/api/v1/business/search')
                            ->setData(['keyword' => 'nrs'])
                            ->send();
                        $data = $response->isOk ? $response->data : [];
//                        echo $data['items'][0]['name'];
//                        echo $data['items'][0]['email'];
                        echo $twig->render('home',
                            array('name' => $data['items'][0]['name'], 'email' => $data['items'][0]['email']));
                    }
                }
            }
        }


        //  return $this->render('index', ['data' => $data]);

    }

    public function actionContact()
    {
        $model = new ContactForm();
        if ($model->load(Yii::$app->request->post())) {
            if ($model->contact(Yii::$app->params['adminEmail'])) {
                Yii::$app->getSession()->setFlash('alert', [
                    'body' => Yii::t('frontend',
                        'Thank you for contacting us. We will respond to you as soon as possible.'),
                    'options' => ['class' => 'alert-success']
                ]);

                return $this->refresh();
            } else {
                Yii::$app->getSession()->setFlash('alert', [
                    'body' => \Yii::t('frontend', 'There was an error sending email.'),
                    'options' => ['class' => 'alert-danger']
                ]);
            }
        }

        return $this->render('contact', [
            'model' => $model
        ]);
    }
}
